# Configuration

Created by Jan Kotanski, last modified on Jul 10, 2018 13:45

The `Configuration` button appears in the top-right corner in the expert mode, i.e.

      $ lavue -m expert

It opens the configuration dialog where the user select matching LaVue settings.

- On normal exit of LaVue the settings are stored at `$HOME/.config/DESY/LaVue.conf`
- The settings are loaded back from: `$HOME/.config/DESY/LaVue.conf` when the user starts LaVue.